%% Salt dome detection using PC
% ===============================================================================
%  Please, cite the following papers in your publication if you use this script.
% ===============================================================================
% M. A. Shafiq, Y. Alaudah, G. AlRegib, and M. Deriche, Phase Congruency for Image understanding with 
% applications in Computational Seismic Interpretation, The 42nd IEEE International Conference on Acoustics, 
% Speech and Signal Processing (ICASSP). The Internet of Signals, New Orleans, USA, March 5-9, 2017.

% If you have found any bugs or have any questions/suggestions, 
% please contact amirshafiq@gatech.edu 

%% Phase cong explaination
clc
clear
close all

N_Four_Coeff = 4;
t_vec   = [0:100]/100;
F_coeff = ones(1,101)*1/2;

Sq_wave = 0.5*[ones(1,length(linspace(0,0.51,50))),-ones(1,length(linspace(0.5,1,51)))];
for i = 1:2:2*N_Four_Coeff
    a = 2/pi/i;
    if i == 1 
        ps(i,:) = a*sin(2*pi*i*t_vec);
        F_coeff(i,:) = a*sin(2*pi*i*t_vec);
    else
        ps(i,:) = a*sin(2*pi*i*t_vec);
        F_coeff(i,:) = F_coeff(i-2,:)+ a*sin(2*pi*i*t_vec);
    end
end

%% Display

figure(10)
plot(t_vec , ps(1:2:2*N_Four_Coeff,:),'--','linewidth',2)
hold on
plot(t_vec , F_coeff(end,:),'-k','linewidth',2)
plot(t_vec ,Sq_wave ,'-g','linewidth',2)
set(gca, 'XTick', []);
set(gca, 'YTick', []);
legend('Fourier Coeff 1','Fourier Coeff 2','Fourier Coeff 3','Fourier Coeff 4','Sum of first 4 coeffs')

